/**********************************************************************
 
	Copyright (C) 2003 Hirohisa MORI <joshua@nichibun.ac.jp>
 
	This program is free software; you can redistribute it 
	and/or modify it under the terms of the GLOBALBASE 
	Library General Public License (G-LGPL) as published by 

	http://www.globalbase.org/
 
	This program is distributed in the hope that it will be 
	useful, but WITHOUT ANY WARRANTY; without even the 
	implied warranty of MERCHANTABILITY or FITNESS FOR A 
	PARTICULAR PURPOSE.

**********************************************************************/


#define STREAM_LIB


#include	"stream.h"
#include	"task.h"

extern SEM stream_lock;

void
s_set_cm(STREAM * s,CODE_METHOD * cm)
{
	lock_task(stream_lock);
	if ( s == 0 )
		goto end;
	if ( s->h.tbl ) {
		(*s->h.cm->close)(0,s->h.cm_work);
		s->h.cm = cm;
		s->h.cm_work = (*s->h.cm->open)();
	}
end:
	unlock_task(stream_lock,"s_set_cr");
}

